summaryrefslogtreecommitdiffstats
path: root/make
diff options
context:
space:
mode:
Diffstat (limited to 'make')
-rw-r--r--make/build-jogl.xml114
-rw-r--r--make/build-nativewindow.xml2
-rw-r--r--make/build-newt.xml108
-rw-r--r--make/build.xml6
-rwxr-xr-xmake/config/jogl/cg-common-CustomJavaCode.java2
-rw-r--r--make/config/jogl/cg-common.cfg4
-rw-r--r--make/config/jogl/cgl-macosx.cfg2
-rwxr-xr-xmake/config/jogl/cglext.cfg4
-rw-r--r--make/config/jogl/egl-common.cfg2
-rwxr-xr-xmake/config/jogl/egl.cfg4
-rwxr-xr-xmake/config/jogl/eglext.cfg6
-rw-r--r--make/config/jogl/gl-common.cfg2
-rwxr-xr-xmake/config/jogl/gl-es1.cfg4
-rwxr-xr-xmake/config/jogl/gl-es2.cfg4
-rw-r--r--make/config/jogl/gl-gl2.cfg4
-rw-r--r--make/config/jogl/gl-gl2es12.cfg4
-rw-r--r--make/config/jogl/gl-gl3.cfg4
-rw-r--r--make/config/jogl/gl-gl3bc.cfg4
-rw-r--r--make/config/jogl/gl-impl-CustomCCode-gl2.c8
-rw-r--r--make/config/jogl/gl-impl-CustomCCode-gl2es12.c8
-rw-r--r--make/config/jogl/gl-impl-CustomCCode-gl3.c8
-rw-r--r--make/config/jogl/gl-impl-CustomCCode-gl3bc.c8
-rw-r--r--make/config/jogl/gl-impl-CustomCCode-gles1.c8
-rw-r--r--make/config/jogl/gl-impl-CustomCCode-gles2.c8
-rwxr-xr-xmake/config/jogl/glu-CustomJavaCode-base.java4
-rwxr-xr-xmake/config/jogl/glu-CustomJavaCode-gl2es1.java2
-rwxr-xr-xmake/config/jogl/glu-base.cfg4
-rw-r--r--make/config/jogl/glu-common.cfg6
-rwxr-xr-xmake/config/jogl/glu-gl2.cfg14
-rwxr-xr-xmake/config/jogl/glu-gl2es1.cfg2
-rwxr-xr-xmake/config/jogl/glx-CustomCCode.c24
-rw-r--r--make/config/jogl/glx-CustomJavaCode.java2
-rw-r--r--make/config/jogl/glx-x11.cfg2
-rwxr-xr-xmake/config/jogl/glxext.cfg6
-rw-r--r--make/config/jogl/wgl-win32.cfg2
-rw-r--r--make/config/jogl/wglext.cfg4
-rw-r--r--make/stub_includes/opengl/gl4.c11
37 files changed, 211 insertions, 200 deletions
diff --git a/make/build-jogl.xml b/make/build-jogl.xml
index c7a8a1853..80b106467 100644
--- a/make/build-jogl.xml
+++ b/make/build-jogl.xml
@@ -95,86 +95,86 @@
<!-- partitioning -->
<property name="java.part.core"
- value="javax/media/opengl/* javax/media/opengl/fixedfunc/* javax/media/opengl/glu/* javax/media/opengl/glu/gl2es1/* com/sun/opengl/impl/* com/sun/opengl/impl/glu/* com/sun/opengl/impl/glu/error/*"/>
+ value="javax/media/opengl/* javax/media/opengl/fixedfunc/* javax/media/opengl/glu/* javax/media/opengl/glu/gl2es1/* com/jogamp/opengl/impl/* com/jogamp/opengl/impl/glu/* com/jogamp/opengl/impl/glu/error/*"/>
<property name="java.part.core.exclude" value="javax/media/opengl/Debug* javax/media/opengl/Trace*"/>
<property name="java.part.nv-cg"
- value="com/sun/opengl/cg com/sun/opengl/cg/*"/>
+ value="com/jogamp/opengl/cg com/jogamp/opengl/cg/*"/>
<property name="java.part.egl"
- value="com/sun/opengl/impl/egl/*"/>
+ value="com/jogamp/opengl/impl/egl/*"/>
<property name="java.part.glutess"
- value="com/sun/opengl/impl/glu/tessellator/**"/>
+ value="com/jogamp/opengl/impl/glu/tessellator/**"/>
<property name="java.part.glumipmap"
- value="com/sun/opengl/impl/glu/mipmap/**"/>
+ value="com/jogamp/opengl/impl/glu/mipmap/**"/>
<property name="java.part.glugl2"
- value="com/sun/opengl/impl/glu/gl2/** com/sun/opengl/impl/glu/nurbs/** com/sun/opengl/impl/glu/registry/** javax/media/opengl/glu/gl2/**"/>
+ value="com/jogamp/opengl/impl/glu/gl2/** com/jogamp/opengl/impl/glu/nurbs/** com/jogamp/opengl/impl/glu/registry/** javax/media/opengl/glu/gl2/**"/>
<property name="java.part.openmax"
value="com/sun/openmax/**"/>
<property name="java.part.sdk"
- value="com/sun/opengl/util/glsl/sdk/**"/>
+ value="com/jogamp/opengl/util/glsl/sdk/**"/>
<property name="java.part.glx"
- value="com/sun/opengl/impl/x11/glx/*"/>
+ value="com/jogamp/opengl/impl/x11/glx/*"/>
<property name="java.part.wgl"
- value="com/sun/opengl/impl/windows/wgl/*"/>
+ value="com/jogamp/opengl/impl/windows/wgl/*"/>
<property name="java.part.cgl"
- value="com/sun/opengl/impl/macosx/cgl/*"/>
+ value="com/jogamp/opengl/impl/macosx/cgl/*"/>
<property name="java.part.gl2es12"
- value="com/sun/opengl/impl/gl2es12/**"/>
+ value="com/jogamp/opengl/impl/gl2es12/**"/>
<property name="java.part.gl3"
- value="com/sun/opengl/impl/**/gl3/**"/>
+ value="com/jogamp/opengl/impl/**/gl3/**"/>
<property name="java.part.gl3.dbg"
value="javax/media/opengl/TraceGL3.* javax/media/opengl/DebugGL3.* javax/media/opengl/TraceGL3bc.* javax/media/opengl/DebugGL3bc.*"/>
<property name="java.part.gl2"
- value="com/sun/opengl/impl/**/gl2/**"/>
+ value="com/jogamp/opengl/impl/**/gl2/**"/>
<property name="java.part.gl2.dbg"
value="javax/media/opengl/TraceGL2.* javax/media/opengl/DebugGL2.* javax/media/opengl/TraceGL2GL3.* javax/media/opengl/DebugGL2GL3.*"/>
<property name="java.part.es1"
- value="javax/media/opengl/**/es1/** com/sun/opengl/**/es1/**"/>
+ value="javax/media/opengl/**/es1/** com/jogamp/opengl/**/es1/**"/>
<property name="java.part.es1.dbg"
value="javax/media/opengl/TraceGLES1.* javax/media/opengl/DebugGLES1.* javax/media/opengl/TraceGL2ES1.* javax/media/opengl/DebugGL2ES1.*"/>
<property name="java.part.es2"
- value="javax/media/opengl/**/es2/** com/sun/opengl/**/es2/**"/>
+ value="javax/media/opengl/**/es2/** com/jogamp/opengl/**/es2/**"/>
<property name="java.part.es2.dbg"
value="javax/media/opengl/TraceGLES2.* javax/media/opengl/DebugGLES2.* javax/media/opengl/TraceGL2ES2.* javax/media/opengl/DebugGL2ES2.*"/>
<property name="java.part.awt"
- value="javax/media/opengl/awt/** com/sun/opengl/impl/**/awt/**"/>
+ value="javax/media/opengl/awt/** com/jogamp/opengl/impl/**/awt/**"/>
<property name="java.part.util"
- value="com/sun/opengl/util/* com/sun/opengl/util/texture/** com/sun/opengl/util/packrect/**"/>
+ value="com/jogamp/opengl/util/* com/jogamp/opengl/util/texture/** com/jogamp/opengl/util/packrect/**"/>
<property name="java.part.util.awt"
- value="com/sun/opengl/util/**/awt/** com/sun/opengl/util/AWTAnimatorImpl*"/>
+ value="com/jogamp/opengl/util/**/awt/** com/jogamp/opengl/util/AWTAnimatorImpl*"/>
<property name="java.part.util.gl2"
- value="com/sun/opengl/util/**/gl2/**"/>
+ value="com/jogamp/opengl/util/**/gl2/**"/>
<property name="java.part.util.glsl"
- value="com/sun/opengl/util/glsl/* com/sun/opengl/util/glsl/fixedfunc/*"/>
+ value="com/jogamp/opengl/util/glsl/* com/jogamp/opengl/util/glsl/fixedfunc/*"/>
<property name="java.part.util.fixedfuncemu"
- value="com/sun/opengl/util/glsl/fixedfunc/impl/**"/>
+ value="com/jogamp/opengl/util/glsl/fixedfunc/impl/**"/>
<property name="java.part.util.fixedfuncemu.shadercode"
- value="com/sun/opengl/util/glsl/fixedfunc/impl/shaders/* com/sun/opengl/util/glsl/fixedfunc/impl/shaders/bin/**"/>
+ value="com/jogamp/opengl/util/glsl/fixedfunc/impl/shaders/* com/jogamp/opengl/util/glsl/fixedfunc/impl/shaders/bin/**"/>
<!-- condition excludes -->
@@ -191,13 +191,13 @@
</condition>
<property name="java.excludes.javadoc.packagenames"
- value="com.sun.opengl.impl.gl2.fixme.*,com.sun.javafx.audio.windows.waveout.TestSpatialization"/>
+ value="com.jogamp.opengl.impl.gl2.fixme.*,com.sun.javafx.audio.windows.waveout.TestSpatialization"/>
<property name="java.excludes.fixme"
- value="com/sun/opengl/impl/gl2/fixme/** com/sun/javafx/audio/windows/waveout/TestSpatialization.java" />
+ value="com/jogamp/opengl/impl/gl2/fixme/** com/sun/javafx/audio/windows/waveout/TestSpatialization.java" />
<property name="java.excludes.cdcfp"
- value="${java.excludes.fixme} ${java.part.nv-cg} ${java.part.gl2} ${java.part.gl2.dbg} ${java.part.gl3} ${java.part.gl3.dbg} ${java.part.awt} ${java.part.glugl2} ${java.part.util.awt} ${java.part.util.gl2} com/sun/opengl/util/TGAWriter.java"/>
+ value="${java.excludes.fixme} ${java.part.nv-cg} ${java.part.gl2} ${java.part.gl2.dbg} ${java.part.gl3} ${java.part.gl3.dbg} ${java.part.awt} ${java.part.glugl2} ${java.part.util.awt} ${java.part.util.gl2} com/jogamp/opengl/util/TGAWriter.java"/>
<condition property="java.excludes.desktop"
value="${java.part.glx} ${java.excludes.cdcfp}">
@@ -310,7 +310,7 @@
<property name="src.generated" value="${build}/gensrc" />
<property name="src.generated.java" value="${src.generated}/classes" />
<property name="src.generated.java-cdc" value="${src.generated}/classes-cdc" />
- <property name="src.generated.java.cg" value="${src.generated.java}/com/sun/opengl/cg" />
+ <property name="src.generated.java.cg" value="${src.generated.java}/com/jogamp/opengl/cg" />
<property name="src.generated.c" value="${src.generated}/native/jogl" />
<property name="src.generated.c.openmax" value="${src.generated}/native/openmax" />
<property name="src.generated.c.cg" value="${src.generated}/native/jogl_cg" />
@@ -468,9 +468,9 @@
<property name="javadoc.overview" value="doc/jogl/spec-overview.html" />
<property name="javadoc.spec.packagenames" value="javax.media.opengl.*" />
- <property name="javadoc.packagenames" value="${javadoc.spec.packagenames},com.sun.opengl.util.*" />
+ <property name="javadoc.packagenames" value="${javadoc.spec.packagenames},com.jogamp.opengl.util.*" />
- <property name="javadoc.dev.packagenames" value="${javadoc.packagenames},com.sun.opengl.impl.*,com.sun.gluegen,com.sun.gluegen.runtime" />
+ <property name="javadoc.dev.packagenames" value="${javadoc.packagenames},com.jogamp.opengl.impl.*,com.sun.gluegen,com.jogamp.gluegen.runtime" />
<property name="javadoc.bottom" value="Copyright 2005 Sun Microsystems, Inc. All rights reserved. Use is subject to &lt;a href=&quot;http://jcp.org/en/jsr/detail?id=231&quot;&gt;license terms&lt;/a&gt;." />
</target>
@@ -498,21 +498,21 @@
</target>
<target name="setup.javacdc">
- <copy file="../src/jogl/classes/com/sun/opengl/impl/SystemUtil.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/sun/opengl/impl/SystemUtil.java" />
- <copy file="../src/jogl/classes/com/sun/opengl/util/BufferUtil.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/sun/opengl/util/BufferUtil.java" />
- <copy file="../src/jogl/classes/com/sun/opengl/impl/InternalBufferUtil.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/sun/opengl/impl/InternalBufferUtil.java" />
- <copy file="../src/jogl/classes/com/sun/opengl/util/texture/TextureIO.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/sun/opengl/util/texture/TextureIO.java" />
- <copy file="../src/jogl/classes/com/sun/opengl/util/texture/spi/DDSImage.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/sun/opengl/util/texture/spi/DDSImage.java" />
- <copy file="../src/jogl/classes/com/sun/opengl/util/texture/spi/TGAImage.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/sun/opengl/util/texture/spi/TGAImage.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/impl/SystemUtil.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/jogamp/opengl/impl/SystemUtil.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/util/BufferUtil.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/jogamp/opengl/util/BufferUtil.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/impl/InternalBufferUtil.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/jogamp/opengl/impl/InternalBufferUtil.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/util/texture/TextureIO.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/jogamp/opengl/util/texture/TextureIO.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/util/texture/spi/DDSImage.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/jogamp/opengl/util/texture/spi/DDSImage.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/util/texture/spi/TGAImage.java.javame_cdc_fp" tofile="${src.generated.java-cdc}/com/jogamp/opengl/util/texture/spi/TGAImage.java" />
</target>
<target name="setup.javase">
- <copy file="../src/jogl/classes/com/sun/opengl/impl/SystemUtil.java.javase" tofile="${src.generated.java}/com/sun/opengl/impl/SystemUtil.java" />
- <copy file="../src/jogl/classes/com/sun/opengl/util/BufferUtil.java.javase" tofile="${src.generated.java}/com/sun/opengl/util/BufferUtil.java" />
- <copy file="../src/jogl/classes/com/sun/opengl/impl/InternalBufferUtil.java.javase" tofile="${src.generated.java}/com/sun/opengl/impl/InternalBufferUtil.java" />
- <copy file="../src/jogl/classes/com/sun/opengl/util/texture/TextureIO.java.javase" tofile="${src.generated.java}/com/sun/opengl/util/texture/TextureIO.java" />
- <copy file="../src/jogl/classes/com/sun/opengl/util/texture/spi/DDSImage.java.javase" tofile="${src.generated.java}/com/sun/opengl/util/texture/spi/DDSImage.java" />
- <copy file="../src/jogl/classes/com/sun/opengl/util/texture/spi/TGAImage.java.javase" tofile="${src.generated.java}/com/sun/opengl/util/texture/spi/TGAImage.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/impl/SystemUtil.java.javase" tofile="${src.generated.java}/com/jogamp/opengl/impl/SystemUtil.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/util/BufferUtil.java.javase" tofile="${src.generated.java}/com/jogamp/opengl/util/BufferUtil.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/impl/InternalBufferUtil.java.javase" tofile="${src.generated.java}/com/jogamp/opengl/impl/InternalBufferUtil.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/util/texture/TextureIO.java.javase" tofile="${src.generated.java}/com/jogamp/opengl/util/texture/TextureIO.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/util/texture/spi/DDSImage.java.javase" tofile="${src.generated.java}/com/jogamp/opengl/util/texture/spi/DDSImage.java" />
+ <copy file="../src/jogl/classes/com/jogamp/opengl/util/texture/spi/TGAImage.java.javase" tofile="${src.generated.java}/com/jogamp/opengl/util/texture/spi/TGAImage.java" />
</target>
<!-- ================================================================== -->
@@ -932,7 +932,7 @@
<!-- Now check for the presence of one well-known file -->
<uptodate property="java.generate.cg.skip">
<srcfiles refid="stub.includes.cg.dependencies.fileset" />
- <mapper type="merge" to="${src.generated.java}/com/sun/opengl/cg/CgGL.java" />
+ <mapper type="merge" to="${src.generated.java}/com/jogamp/opengl/cg/CgGL.java" />
</uptodate>
</target>
@@ -1017,7 +1017,7 @@
<targetfileset dir="${src.generated.java}/javax/media/opengl"
includes="DebugGL2.java,TraceGL2.java" />
</dependset>
-
+
<!-- Now choose one of the two to test to see if we have to regenerate -->
<uptodate property="java.generate.composable.pipeline.skip.gl2"
srcfile="${classes}/javax/media/opengl/GL2.class"
@@ -1119,31 +1119,31 @@
<!-- Blow away the DebugGL*.java and TraceGL*.java sources if GL*.class has changed
(the uptodate element doesn't support arbitrary source and destination files) -->
<dependset>
- <srcfilelist dir="${classes}/com/sun/opengl/util/glsl/fixedfunc" files="FixedFuncHook.class" />
+ <srcfilelist dir="${classes}/com/jogamp/opengl/util/glsl/fixedfunc" files="FixedFuncHook.class" />
<srcfilelist dir="${classes}/javax/media/opengl" files="GL2ES1.class" />
<srcfilelist dir="${classes}/javax/media/opengl" files="GL2ES2.class" />
- <targetfileset dir="${src.generated.java}/com/sun/opengl/util/glsl/fixedfunc/impl"
+ <targetfileset dir="${src.generated.java}/com/jogamp/opengl/util/glsl/fixedfunc/impl"
includes="FixedFuncImpl.java" />
</dependset>
<!-- Now choose one of the two to test to see if we have to regenerate -->
<uptodate property="java.generate.composable.pipeline.custom.skip.glfixfunc"
srcfile="${classes}/javax/media/opengl/GL2ES1.class"
- targetfile="${src.generated.java}/com/sun/opengl/util/glsl/fixedfunc/impl/FixedFuncImpl.java" />
+ targetfile="${src.generated.java}/com/jogamp/opengl/util/glsl/fixedfunc/impl/FixedFuncImpl.java" />
</target>
<target name="java.generate.composable.pipeline.custom.glfixfunc" depends="java.generate.composable.pipeline.custom.check.glfixfunc" unless="java.generate.composable.pipeline.custom.skip.glfixfunc">
<java classname="com.sun.gluegen.opengl.BuildComposablePipeline" fork="yes" failonerror="true">
<arg value="javax.media.opengl.GL2ES1" />
- <arg value="${src.generated.java}/com/sun/opengl/util/glsl/fixedfunc/impl" />
- <arg value="com.sun.opengl.util.glsl.fixedfunc.impl.FixedFuncImpl" />
- <arg value="com.sun.opengl.util.glsl.fixedfunc.impl.FixedFuncHook" />
+ <arg value="${src.generated.java}/com/jogamp/opengl/util/glsl/fixedfunc/impl" />
+ <arg value="com.jogamp.opengl.util.glsl.fixedfunc.impl.FixedFuncImpl" />
+ <arg value="com.jogamp.opengl.util.glsl.fixedfunc.impl.FixedFuncHook" />
<arg value="javax.media.opengl.GL2ES2" />
<arg value="prolog_xor_downstream" />
<classpath refid="pipeline.classpath" />
</java>
<copy todir="${src.generated.java-cdc}">
<fileset dir="${src.generated.java}"
- includes="com/sun/opengl/util/glsl/fixedfunc/impl/FixedFuncImpl.java" />
+ includes="com/jogamp/opengl/util/glsl/fixedfunc/impl/FixedFuncImpl.java" />
</copy>
</target>
<target name="java.generate.composable.pipeline.custom" depends="init, build.gluegen, java.generate.composable.pipeline.custom.glfixfunc">
@@ -1171,7 +1171,7 @@
<copy todir="${src.generated.java-cdc}">
<fileset dir="${src.generated.java}"
includes="**"
- excludes="com/sun/opengl/cg/** com/sun/opengl/impl/gl2/** com/sun/opengl/impl/gl3/** com/sun/opengl/impl/glu/gl2/** javax/media/opengl/glu/gl2/**"/>
+ excludes="com/jogamp/opengl/cg/** com/jogamp/opengl/impl/gl2/** com/jogamp/opengl/impl/gl3/** com/jogamp/opengl/impl/glu/gl2/** javax/media/opengl/glu/gl2/**"/>
</copy>
<copy todir="${classes-cdc}">
<fileset dir="${classes}"
@@ -1182,7 +1182,7 @@
<target name="java.compile.secondpass.javase">
<!-- Perform the second pass Java compile; everything except portion of fixed function emulation depending on generated code. -->
<javac destdir="${classes}"
- excludes="com/sun/opengl/util/glsl/fixedfunc/FixedFuncUtil.java,${java.excludes.all}"
+ excludes="com/jogamp/opengl/util/glsl/fixedfunc/FixedFuncUtil.java,${java.excludes.all}"
source="${jogl.sourcelevel}"
fork="yes"
memoryMaximumSize="${javac.memorymax}"
@@ -1196,7 +1196,7 @@
<target name="java.compile.secondpass.javacdc" unless="setup.noCDC">
<!-- Perform the second pass Java compile; everything except portion of fixed function emulation depending on generated code. -->
<javac destdir="${classes-cdc}"
- excludes="com/sun/opengl/util/glsl/fixedfunc/FixedFuncUtil.java,${java.excludes.all},${java.excludes.cdcfp}"
+ excludes="com/jogamp/opengl/util/glsl/fixedfunc/FixedFuncUtil.java,${java.excludes.all},${java.excludes.cdcfp}"
source="${jogl.sourcelevel}"
bootclasspath="${javac.bootclasspath-cdc.jar}"
fork="yes"
@@ -1823,7 +1823,7 @@
<fileset dir="${classes}">
<include name="javax/media/opengl/**" />
<include name="com/sun/gluegen/runtime/**" />
- <include name="com/sun/opengl/**" />
+ <include name="com/jogamp/opengl/**" />
<include name="${java.part.openmax}" />
<!-- FIXME: this is temporary until we move these classes to another workspace -->
<include name="com/sun/javafx/**" />
@@ -1835,7 +1835,7 @@
<target name="build-jars-all-noawt" depends="setup-manifestfile">
<jar manifest="${build}/tempversion" destfile="${jogl.all-noawt.jar}" filesonly="true">
<fileset dir="${classes}"
- includes="javax/media/opengl/** com/sun/gluegen/runtime/** com/sun/opengl/** ${java.part.openmax} com/sun/javafx/**"
+ includes="javax/media/opengl/** com/sun/gluegen/runtime/** com/jogamp/opengl/** ${java.part.openmax} com/sun/javafx/**"
excludes="${java.part.awt} ${java.part.util.awt}">
</fileset>
<fileset dir="${src.java}"
@@ -1907,7 +1907,7 @@
<jar manifest="${build}/tempversion" destfile="${jogl.util.gl2.jar}" filesonly="true">
<fileset dir="${classes}"
includes="${java.part.util.gl2}"
- excludes="com/sun/opengl/**/awt/**"/>
+ excludes="com/jogamp/opengl/**/awt/**"/>
</jar>
</target>
@@ -1968,7 +1968,7 @@
<!-- Same as above but with Cg directories added -->
<target name="javadoc.cg" depends="load.user.properties,init" if="jogl.cg">
<!-- Build the general public Javadoc with CG -->
- <javadoc packagenames="${javadoc.packagenames},com.sun.opengl.cg"
+ <javadoc packagenames="${javadoc.packagenames},com.jogamp.opengl.cg"
excludepackagenames="${java.excludes.javadoc.packagenames}"
sourcepath="${src.java};${src.generated.java}"
destdir="${javadoc}" windowtitle="${javadoc.windowtitle}"
@@ -2038,7 +2038,7 @@
<!-- Same as above but with Cg directories added -->
<target name="javadoc.dev.cg" if="jogl.cg">
<!-- Build the internal developer Javadoc -->
- <javadoc packagenames="${javadoc.dev.packagenames},com.sun.opengl.cg"
+ <javadoc packagenames="${javadoc.dev.packagenames},com.jogamp.opengl.cg"
excludepackagenames="${java.excludes.javadoc.packagenames}"
sourcepath="${src.java};${src.generated.java}"
destdir="${javadoc.dev}" windowtitle="${javadoc.windowtitle}"
diff --git a/make/build-nativewindow.xml b/make/build-nativewindow.xml
index c0930cb42..776341981 100644
--- a/make/build-nativewindow.xml
+++ b/make/build-nativewindow.xml
@@ -257,7 +257,7 @@
<property name="javadoc.packagenames" value="${javadoc.spec.packagenames}" />
- <property name="javadoc.dev.packagenames" value="${javadoc.packagenames},com.sun.nativewindow.impl.*,com.sun.gluegen,com.sun.gluegen.runtime" />
+ <property name="javadoc.dev.packagenames" value="${javadoc.packagenames},com.sun.nativewindow.impl.*,com.sun.gluegen,com.jogamp.gluegen.runtime" />
<property name="javadoc.bottom" value="Copyright 2005 Sun Microsystems, Inc. All rights reserved. Use is subject to &lt;a href=&quot;http://jcp.org/en/jsr/detail?id=231&quot;&gt;license terms&lt;/a&gt;." />
</target>
diff --git a/make/build-newt.xml b/make/build-newt.xml
index e74a036bb..df5783319 100644
--- a/make/build-newt.xml
+++ b/make/build-newt.xml
@@ -27,14 +27,14 @@
- Java and C file generators. Note that it is only supported
- to create the Javadoc for the platform on which you are
- currently running.
- -
+ -
- Note: on Windows the "win32.c.compiler" property in newt.properties
- is required to select the appropriate C compiler. See the example
- newt.properties in this directory for valid values. On Mac OS X
- universal binaries may also be built by setting the "macosxfat"
- property in newt.properties; again see the example file in this
- directory.
- -
+ -
- Thanks to Rob Grzywinski and Artur Biesiadowski for the bulk of the
- ANT build, including the GlueGen and StaticGLInfo tasks, the building of
- the Java generated sources, the first and second phase Java compiles, and
@@ -63,7 +63,7 @@
<import file="${gluegen.root}/make/gluegen-cpptasks.xml" />
<!-- ================================================================== -->
- <!--
+ <!--
- Base initialization and detection of operating system.
-->
<target name="base.init" depends="gluegen.cpptasks.detect.os">
@@ -79,7 +79,7 @@
</condition>
<condition property="setup.noall">
- <isset property="setup.noAWT"/>
+ <isset property="setup.noAWT"/>
</condition>
<condition property="setup.nonatives">
@@ -132,19 +132,19 @@
<condition property="java.excludes.awt"
value="${java.part.awt}">
- <isset property="setup.noAWT"/>
+ <isset property="setup.noAWT"/>
</condition>
<condition property="java.excludes.opengl"
value="${java.part.opengl} ${java.part.broadcomegl}">
- <isset property="setup.noOpenGL"/>
+ <isset property="setup.noOpenGL"/>
</condition>
<property name="java.excludes.cdcfp" value="${java.part.awt}"/>
<condition property="java.excludes.desktop"
value="${java.part.x11} ${java.part.windows}, ${java.part.macosx}, ${java.part.awt}">
- <isset property="setup.nodesktop"/>
+ <isset property="setup.nodesktop"/>
</condition>
<property name="java.excludes.all" value="${java.excludes.awt}, ${java.excludes.opengl} ${java.excludes.desktop}" />
@@ -153,7 +153,7 @@
<!-- Set the project root directory to be up one directory. -->
<property name="project.root" value=".." />
-
+
<!-- Set the configuration and build files to this directory. -->
<property name="make" value="." />
</target>
@@ -167,7 +167,7 @@
</target-->
<!-- ================================================================== -->
- <!--
+ <!--
- Load user properties which override build defaults.
-->
<target name="load.user.properties" depends="base.init,base.init.sourcelevel.1" unless="user.properties.file">
@@ -182,17 +182,17 @@
</target>
<!-- ================================================================== -->
- <!--
+ <!--
- Declare all paths and user defined variables.
-->
<target name="declare.common" description="Declare properties" depends="load.user.properties">
- <!-- The location and name of the configuration ANT file that will
+ <!-- The location and name of the configuration ANT file that will
- validate to ensure that all user-define variables are set. -->
<property name="validate.user.properties" value="${make}/validate-properties.xml" />
-
+
<!-- NOTE: the value of the debug and optimise attributes will not be overridden if already set externally -->
- <property name="javacdebug" value="true" />
- <property name="javacdebuglevel" value="source,lines" />
+ <property name="javacdebug" value="true" />
+ <property name="javacdebuglevel" value="source,lines" />
<!-- Names of directories relative to the project root.
Some of these are used in FileMappers later for dependence information
@@ -226,7 +226,7 @@
<property name="src.java" value="${project.root}/${rootrel.src.java}" />
<property name="src.c" value="${project.root}/${rootrel.src.c}" />
<property name="build" value="${project.root}/${rootrel.build.newt}" />
-
+
<!-- The generated source directories. -->
<property name="src.generated" value="${build}/gensrc" />
<property name="src.generated.c" value="${src.generated}/native/newt" />
@@ -286,16 +286,16 @@
<property name="javadoc.dev.packagenames" value="${javadoc.packagenames},com.sun.javafx.newt.*" />
<property name="javadoc.bottom" value="Copyright 2005 Sun Microsystems, Inc. All rights reserved. Use is subject to &lt;a href=&quot;http://jcp.org/en/jsr/detail?id=231&quot;&gt;license terms&lt;/a&gt;." />
</target>
-
+
<!-- ================================================================== -->
- <!--
+ <!--
- Initialize all parameters required for the build and create any
- required directories.
-->
<target name="init" depends="declare.common">
<!-- Call the external config validator script to make sure the config is ok and consistent -->
<ant antfile="${validate.user.properties}" inheritall="true"/>
-
+
<mkdir dir="${src.generated.c}" />
<mkdir dir="${src.generated.c}/X11" />
<mkdir dir="${src.generated.c}/MacOSX" />
@@ -309,7 +309,7 @@
</target>
<!-- ================================================================== -->
- <!--
+ <!--
- Compile the original and generated source.
-->
<target name="java.compile.javase">
@@ -342,7 +342,7 @@
<target name="java.compile" depends="java.compile.javase,java.compile.javacdc" />
<!-- ================================================================== -->
- <!--
+ <!--
- Compile the native C code for JOGL (and optionally the Cg binding).
-->
@@ -356,7 +356,7 @@
</compiler>
<!-- linker configuration -->
-
+
<linker id="linker.cfg.linux.newt.broadcom_egl" extends="linker.cfg.linux">
<syslibset dir="/nfsroot/lg/lib" libs="EGL"/>
<syslibset dir="/nfsroot/lg/lib" libs="GLES_CM"/>
@@ -409,7 +409,7 @@
<property name="linker.cfg.id.core" value="linker.cfg.win32.msvc" />
<property name="linker.cfg.id.oswin" value="linker.cfg.win32.msvc.newt" />
</target>
-
+
<target name="c.configure.win32.mingw" if="isMingW">
<echo message="Win32.MingW" />
<property name="compiler.cfg.id" value="compiler.cfg.win32.mingw" />
@@ -427,7 +427,7 @@
</condition>
<echo message="linker.cfg.id.oswin ${linker.cfg.id.oswin}" />
</target>
-
+
<target name="c.configure.linux.amd64" if="isLinuxAMD64">
<echo message="Linux.AMD64" />
<property name="compiler.cfg.id" value="compiler.cfg.linux.amd64" />
@@ -438,7 +438,7 @@
</condition>
<echo message="linker.cfg.id.oswin ${linker.cfg.id.oswin}" />
</target>
-
+
<target name="c.configure.linux.ia64" if="isLinuxIA64">
<echo message="Linux.IA64" />
<property name="compiler.cfg.id" value="compiler.cfg.linux" />
@@ -454,15 +454,15 @@
<property name="linker.cfg.id.core" value="linker.cfg.solaris" />
<property name="linker.cfg.id.oswin" value="linker.cfg.solaris.newt.x11" />
</target>
-
-
+
+
<target name="c.configure.solaris.sparcv9" depends="c.configure.x11" if="isSolarisSparcv9">
<echo message="SolarisSparcv9" />
<property name="compiler.cfg.id" value="compiler.cfg.solaris.sparcv9" />
<property name="linker.cfg.id.core" value="linker.cfg.solaris.sparcv9" />
<property name="linker.cfg.id.oswin" value="linker.cfg.solaris.sparcv9.newt.x11" />
</target>
-
+
<target name="c.configure.solaris.amd64" depends="c.configure.x11" if="isSolarisAMD64">
<echo message="SolarisAMD64" />
@@ -470,7 +470,7 @@
<property name="linker.cfg.id.core" value="linker.cfg.solaris.amd64" />
<property name="linker.cfg.id.oswin" value="linker.cfg.solaris.amd64.newt.x11" />
</target>
-
+
<target name="c.configure.freebsd" depends="c.configure.x11" if="isFreeBSD">
<echo message="FreeBSD" />
<property name="compiler.cfg.id" value="compiler.cfg.freebsd.newt" />
@@ -494,7 +494,7 @@
<property name="linker.cfg.id.core" value="linker.cfg.macosx" />
<property name="linker.cfg.id.oswin" value="linker.cfg.macosx.newt" />
</target>
-
+
<target name="c.configure.2" depends="c.configure.win32,c.configure.linux,c.configure.solaris32,c.configure.solaris.sparcv9,c.configure.solaris.amd64,c.configure.macosx,c.configure.freebsd,c.configure.hpux" />
<target name="c.configure" depends="c.configure.1,c.configure.2" />
@@ -518,9 +518,9 @@
<echo message="Output lib name = @{output.lib.name}" />
<!-- NOTE: the value of the debug and optimise attributes will not be overridden if already set externally -->
- <property name="c.compiler.debug" value="false" />
- <!-- Optimise flags one of { none, size, speed, minimal, full, aggressive, extreme, unsafe } -->
- <property name="c.compiler.optimise" value="none" />
+ <property name="c.compiler.debug" value="false" />
+ <!-- Optimise flags one of { none, size, speed, minimal, full, aggressive, extreme, unsafe } -->
+ <property name="c.compiler.optimise" value="none" />
<condition property="c.compiler.use-debug"><istrue value="${c.compiler.debug}"/></condition>
@@ -535,25 +535,25 @@
<echo message="Compiling @{output.lib.name}" />
- <cc outtype="shared"
- objdir="${obj}"
+ <cc outtype="shared"
+ objdir="${obj}"
outfile="${obj}/@{output.lib.name}"
- optimize="${c.compiler.optimise}"
+ optimize="${c.compiler.optimise}"
debug="${c.compiler.debug}"
- multithreaded="true"
- exceptions="false"
- rtti="false">
-
+ multithreaded="true"
+ exceptions="false"
+ rtti="false">
+
<!-- TODO: versioninfo companyname="java.net"
legalcopyright="Copyright"
- productname="JOGL"
+ productname="JOGL"
productversion="x.y.z"
description="Description"
- fileversion="x.y.z"
- filecomments="File Comment" /-->
-
+ fileversion="x.y.z"
+ filecomments="File Comment" /-->
+
<fileset dir="${project.root}"><patternset refid="@{c.compiler.src.files}"/></fileset>
-
+
<compiler extends="@{compiler.cfg.id}" >
<sysincludepath path="${java.includes.dir}"/>
<sysincludepath path="${java.includes.dir.platform}"/>
@@ -567,11 +567,11 @@
<includepath path="${src.generated.c}/IntelGDL" if="useIntelGDL" />
<includepath path="stub_includes/embedded/IntelGDL" if="useIntelGDL" />
<includepath path="${src.generated.c}/BroadcomEGL" if="useBroadcomEGL" />
-
+
<!-- This must come last to not override real include paths -->
<!-- includepath path="stub_includes/macosx" if="isOSX" / -->
</compiler>
-
+
<linker extends="@{linker.cfg.id}">
<syslibset dir="${java.lib.dir.platform}" libs="jawt" if="@{output.lib.name}.useLibJAWT"/>
<syslibset dir="${java.lib.dir.platform}/server" libs="jvm" if="@{output.lib.name}.useLibJVM"/>
@@ -593,7 +593,7 @@
<param name="dest" value="${build}/obj/@{output.lib.name}.dll" />
</antcall>
</sequential>
- </macrodef>
+ </macrodef>
<target name="c.build.newt.prepare.KD" if="useKD">
<javah destdir="${src.generated.c}/KD" classpath="${classes}" class="com.sun.javafx.newt.opengl.kd.KDWindow" />
@@ -797,17 +797,17 @@
<!-- ================================================================== -->
<!--
- Build the Javadocs for the sources.
- - NOTE: these are not entirely correct as the javadocs targets depend
- - on the platform specific build targets. To circumvent any
+ - NOTE: these are not entirely correct as the javadocs targets depend
+ - on the platform specific build targets. To circumvent any
- errors, ensure that the source is built first.
-->
<target name="javadoc" depends="load.user.properties,init">
<!-- Build the general Javadoc -->
<javadoc packagenames="${javadoc.packagenames}"
excludepackagenames="${java.excludes.javadoc.packagenames}"
- sourcepath="${src.java};${src.generated.java}"
+ sourcepath="${src.java};${src.generated.java}"
destdir="${javadoc}" windowtitle="${javadoc.windowtitle}"
- overview="${javadoc.overview}"
+ overview="${javadoc.overview}"
source="1.4"
linkoffline="${javadoc.link} 142-packages"
bottom="${javadoc.bottom}" >
@@ -828,14 +828,14 @@
<classpath refid="nativewindow_gluegen_jogl.classpath"/>
</javadoc>
</target>
-
+
<target name="javadoc.dev" depends="load.user.properties,init">
<!-- Build the internal developer Javadoc -->
<javadoc packagenames="${javadoc.dev.packagenames}"
excludepackagenames="${java.excludes.javadoc.packagenames}"
- sourcepath="${src.java};${src.generated.java}"
+ sourcepath="${src.java};${src.generated.java}"
destdir="${javadoc.dev}" windowtitle="${javadoc.windowtitle}"
- overview="${javadoc.overview}"
+ overview="${javadoc.overview}"
source="1.4"
linkoffline="${javadoc.link} 142-packages"
bottom="${javadoc.bottom}" >
diff --git a/make/build.xml b/make/build.xml
index b8b3872ca..cd3ee2ab9 100644
--- a/make/build.xml
+++ b/make/build.xml
@@ -43,12 +43,12 @@
<property name="javadoc.spec.packagenames" value="javax.media.opengl.*" />
<property name="javadoc.windowtitle" value="JOGL, NativeWindow and NEWT APIs" />
- <property name="javadoc.packagenames" value="${javadoc.nw.spec.packagenames},${javadoc.spec.packagenames},com.sun.opengl.util.*,com.sun.javafx.newt, com.sun.javafx.newt.opengl" />
+ <property name="javadoc.packagenames" value="${javadoc.nw.spec.packagenames},${javadoc.spec.packagenames},com.jogamp.opengl.util.*,com.sun.javafx.newt, com.sun.javafx.newt.opengl" />
<property name="javadoc.dev" value="${project.root}/javadoc_dev" />
- <property name="javadoc.dev.packagenames" value="${javadoc.packagenames},com.sun.opengl.impl.*,com.sun.nativewindow.impl.*,com.sun.javafx.newt.*,com.sun.gluegen,com.sun.gluegen.runtime" />
+ <property name="javadoc.dev.packagenames" value="${javadoc.packagenames},com.jogamp.opengl.impl.*,com.sun.nativewindow.impl.*,com.sun.javafx.newt.*,com.sun.gluegen,com.jogamp.gluegen.runtime" />
- <property name="java.excludes.javadoc.packagenames" value="com.sun.opengl.impl.gl2.fixme.*,com.sun.javafx.audio.windows.waveout.TestSpatialization"/>
+ <property name="java.excludes.javadoc.packagenames" value="com.jogamp.opengl.impl.gl2.fixme.*,com.sun.javafx.audio.windows.waveout.TestSpatialization"/>
<property name="javadoc.bottom" value="Copyright 2005 Sun Microsystems, Inc. All rights reserved. Use is subject to &lt;a href=&quot;http://jcp.org/en/jsr/detail?id=231&quot;&gt;license terms&lt;/a&gt;." />
<property name="gluegen.jar" value="${gluegen.root}/${rootrel.build}/gluegen.jar" />
diff --git a/make/config/jogl/cg-common-CustomJavaCode.java b/make/config/jogl/cg-common-CustomJavaCode.java
index 1f109d9f6..974e24bf4 100755
--- a/make/config/jogl/cg-common-CustomJavaCode.java
+++ b/make/config/jogl/cg-common-CustomJavaCode.java
@@ -1,5 +1,5 @@
static {
- com.sun.opengl.impl.NativeLibLoader.loadCgImpl();
+ com.jogamp.opengl.impl.NativeLibLoader.loadCgImpl();
}
/** A convenience method which reads all available data from the InputStream and then calls cgCreateProgram. */
diff --git a/make/config/jogl/cg-common.cfg b/make/config/jogl/cg-common.cfg
index 9b8dba079..e9ff9d907 100644
--- a/make/config/jogl/cg-common.cfg
+++ b/make/config/jogl/cg-common.cfg
@@ -1,6 +1,6 @@
# This .cfg file provides common options used among all Cg glue code
# generated for Jogl on all platforms.
-Package com.sun.opengl.cg
+Package com.jogamp.opengl.cg
JavaClass CgGL
Style AllStatic
JavaOutputDir gensrc/classes
@@ -97,7 +97,7 @@ Ignore cgGetProgramOptions
#
Import java.nio.*
# And NativeLibLoader for help loading the native libraries
-Import com.sun.opengl.impl.*
+Import com.jogamp.opengl.impl.*
#
# NIODirectOnly directives for routines requiring them for semantic reasons
diff --git a/make/config/jogl/cgl-macosx.cfg b/make/config/jogl/cgl-macosx.cfg
index 54b4be171..f2af29e00 100644
--- a/make/config/jogl/cgl-macosx.cfg
+++ b/make/config/jogl/cgl-macosx.cfg
@@ -3,7 +3,7 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/MacOSX
-Package com.sun.opengl.impl.macosx.cgl
+Package com.jogamp.opengl.impl.macosx.cgl
JavaClass CGL
Style allstatic
Include gl-common.cfg
diff --git a/make/config/jogl/cglext.cfg b/make/config/jogl/cglext.cfg
index 3bd027c84..404a852b0 100755
--- a/make/config/jogl/cglext.cfg
+++ b/make/config/jogl/cglext.cfg
@@ -6,10 +6,10 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/MacOSX
-Package com.sun.opengl.impl.macosx.cgl
+Package com.jogamp.opengl.impl.macosx.cgl
Style InterfaceAndImpl
JavaClass CGLExt
-ImplPackage com.sun.opengl.impl.macosx.cgl
+ImplPackage com.jogamp.opengl.impl.macosx.cgl
ImplJavaClass CGLExtImpl
Include gl-common.cfg
Include gl-desktop.cfg
diff --git a/make/config/jogl/egl-common.cfg b/make/config/jogl/egl-common.cfg
index bcda00b07..01b681b87 100644
--- a/make/config/jogl/egl-common.cfg
+++ b/make/config/jogl/egl-common.cfg
@@ -8,7 +8,7 @@ Import java.nio.*
Import java.util.*
Import javax.media.opengl.*
Import javax.media.opengl.fixedfunc.*
-Import com.sun.opengl.impl.*
+Import com.jogamp.opengl.impl.*
# Treat all of the EGL types as opaque longs
# Opaque long EGLConfig
diff --git a/make/config/jogl/egl.cfg b/make/config/jogl/egl.cfg
index 086152b4f..74047072b 100755
--- a/make/config/jogl/egl.cfg
+++ b/make/config/jogl/egl.cfg
@@ -3,7 +3,7 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/egl
-Package com.sun.opengl.impl.egl
+Package com.jogamp.opengl.impl.egl
JavaClass EGL
Style allstatic
# Shouldn't matter which one of these we pick up
@@ -47,4 +47,4 @@ CustomJavaCode EGL return dispatch_eglGetProcAddress1(procname, eglGetProcAdd
CustomJavaCode EGL }
-Import com.sun.gluegen.runtime.opengl.GLProcAddressHelper
+Import com.jogamp.gluegen.runtime.opengl.GLProcAddressHelper
diff --git a/make/config/jogl/eglext.cfg b/make/config/jogl/eglext.cfg
index fedff35e9..40239371d 100755
--- a/make/config/jogl/eglext.cfg
+++ b/make/config/jogl/eglext.cfg
@@ -3,15 +3,15 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/egl
-Package com.sun.opengl.impl.egl
+Package com.jogamp.opengl.impl.egl
Style InterfaceAndImpl
JavaClass EGLExt
-ImplPackage com.sun.opengl.impl.egl
+ImplPackage com.jogamp.opengl.impl.egl
ImplJavaClass EGLExtImpl
# Shouldn't matter which one of these we pick up
Include egl-common.cfg
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/sun/opengl/impl/egl/EGL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/impl/egl/EGL.java
HierarchicalNativeOutput false
diff --git a/make/config/jogl/gl-common.cfg b/make/config/jogl/gl-common.cfg
index d9d66323a..022c272df 100644
--- a/make/config/jogl/gl-common.cfg
+++ b/make/config/jogl/gl-common.cfg
@@ -12,7 +12,7 @@ Import java.nio.*
Import java.util.*
Import javax.media.opengl.*
Import javax.media.opengl.fixedfunc.*
-Import com.sun.opengl.impl.*
+Import com.jogamp.opengl.impl.*
#####################################################################
# Mostly desktop OpenGL stuff below
diff --git a/make/config/jogl/gl-es1.cfg b/make/config/jogl/gl-es1.cfg
index 867ef8a83..da2267186 100755
--- a/make/config/jogl/gl-es1.cfg
+++ b/make/config/jogl/gl-es1.cfg
@@ -17,7 +17,7 @@ JavaClass GLES1
Extends GLES1 GLBase
Extends GLES1 GL
Extends GLES1 GL2ES1
-ImplPackage com.sun.opengl.impl.es1
+ImplPackage com.jogamp.opengl.impl.es1
ImplJavaClass GLES1Impl
Implements GLES1Impl GLBase
Implements GLES1Impl GL
@@ -97,4 +97,4 @@ IncludeAs CustomCCode gl-impl-CustomCCode-gles1.c
Import javax.media.opengl.GLES1
Import javax.media.opengl.GLES2
Import javax.media.opengl.GL2
-Import com.sun.opengl.impl.InternalBufferUtil
+Import com.jogamp.opengl.impl.InternalBufferUtil
diff --git a/make/config/jogl/gl-es2.cfg b/make/config/jogl/gl-es2.cfg
index f78001dee..fd11ffcf0 100755
--- a/make/config/jogl/gl-es2.cfg
+++ b/make/config/jogl/gl-es2.cfg
@@ -12,7 +12,7 @@ JavaClass GLES2
Extends GLES2 GLBase
Extends GLES2 GL
Extends GLES2 GL2ES2
-ImplPackage com.sun.opengl.impl.es2
+ImplPackage com.jogamp.opengl.impl.es2
ImplJavaClass GLES2Impl
Implements GLES2Impl GLBase
Implements GLES2Impl GL
@@ -79,6 +79,6 @@ Import javax.media.opengl.GLES2
Import javax.media.opengl.GL2
Import javax.media.opengl.GLArrayData
Import javax.media.opengl.GLUniformData
-Import com.sun.opengl.impl.InternalBufferUtil
+Import com.jogamp.opengl.impl.InternalBufferUtil
Import java.io.PrintStream
diff --git a/make/config/jogl/gl-gl2.cfg b/make/config/jogl/gl-gl2.cfg
index 820243ff5..37452d159 100644
--- a/make/config/jogl/gl-gl2.cfg
+++ b/make/config/jogl/gl-gl2.cfg
@@ -19,7 +19,7 @@ Extends GL2 GL
Extends GL2 GL2ES1
Extends GL2 GL2ES2
Extends GL2 GL2GL3
-ImplPackage com.sun.opengl.impl.gl2
+ImplPackage com.jogamp.opengl.impl.gl2
ImplJavaClass GL2Impl
Implements GL2Impl GLBase
Implements GL2Impl GL
@@ -79,5 +79,5 @@ Import javax.media.opengl.GLES2
Import javax.media.opengl.GL2
Import javax.media.opengl.GLArrayData
Import javax.media.opengl.GLUniformData
-Import com.sun.opengl.impl.InternalBufferUtil
+Import com.jogamp.opengl.impl.InternalBufferUtil
Import java.io.PrintStream
diff --git a/make/config/jogl/gl-gl2es12.cfg b/make/config/jogl/gl-gl2es12.cfg
index 232116a61..3942b1419 100644
--- a/make/config/jogl/gl-gl2es12.cfg
+++ b/make/config/jogl/gl-gl2es12.cfg
@@ -11,7 +11,7 @@ ExtendedInterfaceSymbolsOnly ../src/jogl/classes/javax/media/opengl/fixedfunc/GL
ExtendedInterfaceSymbolsOnly ../src/jogl/classes/javax/media/opengl/fixedfunc/GLLightingFunc.java
Style ImplOnly
-ImplPackage com.sun.opengl.impl.gl2es12
+ImplPackage com.jogamp.opengl.impl.gl2es12
ImplJavaClass GL2ES12Impl
Implements GL2ES12Impl GLBase
Implements GL2ES12Impl GL
@@ -86,5 +86,5 @@ IncludeAs CustomCCode gl-impl-CustomCCode-gl2es12.c
Import javax.media.opengl.GLES1
Import javax.media.opengl.GLES2
-Import com.sun.opengl.impl.InternalBufferUtil
+Import com.jogamp.opengl.impl.InternalBufferUtil
Import java.io.PrintStream
diff --git a/make/config/jogl/gl-gl3.cfg b/make/config/jogl/gl-gl3.cfg
index 9f0ea05a8..0bfe2cc38 100644
--- a/make/config/jogl/gl-gl3.cfg
+++ b/make/config/jogl/gl-gl3.cfg
@@ -14,7 +14,7 @@ Extends GL3 GLBase
Extends GL3 GL
Extends GL3 GL2ES2
Extends GL3 GL2GL3
-ImplPackage com.sun.opengl.impl.gl3
+ImplPackage com.jogamp.opengl.impl.gl3
ImplJavaClass GL3Impl
Implements GL3Impl GLBase
Implements GL3Impl GL
@@ -70,5 +70,5 @@ Import javax.media.opengl.GLES2
Import javax.media.opengl.GL3
Import javax.media.opengl.GLArrayData
Import javax.media.opengl.GLUniformData
-Import com.sun.opengl.impl.InternalBufferUtil
+Import com.jogamp.opengl.impl.InternalBufferUtil
Import java.io.PrintStream
diff --git a/make/config/jogl/gl-gl3bc.cfg b/make/config/jogl/gl-gl3bc.cfg
index d2525735e..a637df941 100644
--- a/make/config/jogl/gl-gl3bc.cfg
+++ b/make/config/jogl/gl-gl3bc.cfg
@@ -23,7 +23,7 @@ Extends GL3bc GL2ES2
Extends GL3bc GL2GL3
Extends GL3bc GL2
Extends GL3bc GL3
-ImplPackage com.sun.opengl.impl.gl3
+ImplPackage com.jogamp.opengl.impl.gl3
ImplJavaClass GL3bcImpl
Implements GL3bcImpl GLBase
Implements GL3bcImpl GL
@@ -97,5 +97,5 @@ Import javax.media.opengl.GL2GL3
Import javax.media.opengl.GL2
Import javax.media.opengl.GL3
Import javax.media.opengl.GL3bc
-Import com.sun.opengl.impl.InternalBufferUtil
+Import com.jogamp.opengl.impl.InternalBufferUtil
Import java.io.PrintStream
diff --git a/make/config/jogl/glu-CustomJavaCode-base.java b/make/config/jogl/glu-CustomJavaCode-base.java
index 78c067606..aeb4f2ef9 100755
--- a/make/config/jogl/glu-CustomJavaCode-base.java
+++ b/make/config/jogl/glu-CustomJavaCode-base.java
@@ -169,7 +169,7 @@ protected static boolean checkedGLUtessellatorImpl = false;
protected static final void validateGLUtessellatorImpl() {
if(!checkedGLUtessellatorImpl) {
- availableGLUtessellatorImpl = NWReflection.isClassAvailable("com.sun.opengl.impl.glu.tessellator.GLUtessellatorImpl");
+ availableGLUtessellatorImpl = NWReflection.isClassAvailable("com.jogamp.opengl.impl.glu.tessellator.GLUtessellatorImpl");
checkedGLUtessellatorImpl = true;
}
if(!availableGLUtessellatorImpl) {
@@ -1220,7 +1220,7 @@ protected static final void validateGLUquadricImpl() {
if(!checkedGLUquadricImpl) {
synchronized (syncObject) {
if(!checkedGLUquadricImpl) {
- availableGLUquadricImpl = NWReflection.isClassAvailable("com.sun.opengl.impl.glu.GLUquadricImpl");
+ availableGLUquadricImpl = NWReflection.isClassAvailable("com.jogamp.opengl.impl.glu.GLUquadricImpl");
checkedGLUquadricImpl = true;
}
}
diff --git a/make/config/jogl/glu-CustomJavaCode-gl2es1.java b/make/config/jogl/glu-CustomJavaCode-gl2es1.java
index 8afc28c15..b5cb3b2f8 100755
--- a/make/config/jogl/glu-CustomJavaCode-gl2es1.java
+++ b/make/config/jogl/glu-CustomJavaCode-gl2es1.java
@@ -86,7 +86,7 @@ protected static boolean checkedMipmap = false;
protected static final void validateMipmap() {
if(!checkedMipmap) {
- availableMipmap = NWReflection.isClassAvailable("com.sun.opengl.impl.glu.mipmap.Mipmap");
+ availableMipmap = NWReflection.isClassAvailable("com.jogamp.opengl.impl.glu.mipmap.Mipmap");
checkedMipmap = true;
}
if(!availableMipmap) {
diff --git a/make/config/jogl/glu-base.cfg b/make/config/jogl/glu-base.cfg
index f67673a78..d859225ec 100755
--- a/make/config/jogl/glu-base.cfg
+++ b/make/config/jogl/glu-base.cfg
@@ -20,8 +20,8 @@ Ignore gluScaleImage
IncludeAs CustomJavaCode GLU glu-CustomJavaCode-base.java
# Imports for the Error and Registry classes
-Import com.sun.opengl.impl.glu.error.Error
-Import com.sun.opengl.impl.glu.registry.Registry
+Import com.jogamp.opengl.impl.glu.error.Error
+Import com.jogamp.opengl.impl.glu.registry.Registry
Include glu-common.cfg
diff --git a/make/config/jogl/glu-common.cfg b/make/config/jogl/glu-common.cfg
index df59175bb..28a075954 100644
--- a/make/config/jogl/glu-common.cfg
+++ b/make/config/jogl/glu-common.cfg
@@ -12,9 +12,9 @@ TagNativeBinding true
Import java.nio.*
Import javax.media.opengl.*
Import javax.media.opengl.glu.*
-Import com.sun.opengl.impl.*
-Import com.sun.opengl.impl.glu.*
-Import com.sun.opengl.impl.glu.tessellator.GLUtessellatorImpl
+Import com.jogamp.opengl.impl.*
+Import com.jogamp.opengl.impl.glu.*
+Import com.jogamp.opengl.impl.glu.tessellator.GLUtessellatorImpl
Import com.sun.nativewindow.impl.NWReflection
# Raise GLException instead of RuntimeException in glue code
diff --git a/make/config/jogl/glu-gl2.cfg b/make/config/jogl/glu-gl2.cfg
index 712f9a305..cc5b16f0f 100755
--- a/make/config/jogl/glu-gl2.cfg
+++ b/make/config/jogl/glu-gl2.cfg
@@ -25,7 +25,7 @@ CustomCCode #endif
Include ../intptr.cfg
EmitProcAddressTable true
-ProcAddressTablePackage com.sun.opengl.impl.glu.gl2
+ProcAddressTablePackage com.jogamp.opengl.impl.glu.gl2
ProcAddressTableClassName GLUgl2ProcAddressTable
GetProcAddressTableExpr getGLUProcAddressTable()
@@ -38,14 +38,14 @@ IncludeAs CustomJavaCode GLUgl2 glu-CustomJavaCode-gl2.java
# GLU needs access to the GLUtesselatorImpl class for GLUtesselator,
# to the Mipmap class for scaling and mipmap generation,
# and to the nurbs.* package for the NURBS functionality
-Import com.sun.opengl.impl.glu.nurbs.*
+Import com.jogamp.opengl.impl.glu.nurbs.*
Import java.security.*
-Import com.sun.gluegen.runtime.opengl.GLProcAddressHelper
-Import com.sun.opengl.impl.glu.gl2.nurbs.*
-Import com.sun.opengl.impl.glu.mipmap.Mipmap
-Import com.sun.opengl.impl.glu.gl2.*
+Import com.jogamp.gluegen.runtime.opengl.GLProcAddressHelper
+Import com.jogamp.opengl.impl.glu.gl2.nurbs.*
+Import com.jogamp.opengl.impl.glu.mipmap.Mipmap
+Import com.jogamp.opengl.impl.glu.gl2.*
Import javax.media.opengl.GL2
-Import com.sun.opengl.impl.gl2.ProjectDouble
+Import com.jogamp.opengl.impl.gl2.ProjectDouble
#
# ------------------------
diff --git a/make/config/jogl/glu-gl2es1.cfg b/make/config/jogl/glu-gl2es1.cfg
index 8927f96b9..af89014f4 100755
--- a/make/config/jogl/glu-gl2es1.cfg
+++ b/make/config/jogl/glu-gl2es1.cfg
@@ -20,7 +20,7 @@ Ignore gluScaleImage
IncludeAs CustomJavaCode GLUgl2es1 glu-CustomJavaCode-gl2es1.java
Import javax.media.opengl.GLES1
-Import com.sun.opengl.impl.glu.mipmap.Mipmap
+Import com.jogamp.opengl.impl.glu.mipmap.Mipmap
Include glu-common.cfg
diff --git a/make/config/jogl/glx-CustomJavaCode.java b/make/config/jogl/glx-CustomJavaCode.java
index 3cb1d3619..56057377a 100644
--- a/make/config/jogl/glx-CustomJavaCode.java
+++ b/make/config/jogl/glx-CustomJavaCode.java
@@ -13,7 +13,7 @@
/** Interface to C language function: <br> - Alias for: <br> <code> GLXFBConfig * glXChooseFBConfigSGIX, glXChooseFBConfig(Display * dpy, int screen, const int * attribList, int * nitems); </code> */
- public static com.sun.gluegen.runtime.PointerBuffer glXChooseFBConfigCopied(long dpy, int screen, int[] attribList, int attribList_offset, int[] nitems, int nitems_offset)
+ public static com.jogamp.gluegen.runtime.PointerBuffer glXChooseFBConfigCopied(long dpy, int screen, int[] attribList, int attribList_offset, int[] nitems, int nitems_offset)
{
if(attribList != null && attribList.length <= attribList_offset)
throw new GLException("array offset argument \"attribList_offset\" (" + attribList_offset + ") equals or exceeds array length (" + attribList.length + ")");
diff --git a/make/config/jogl/glx-x11.cfg b/make/config/jogl/glx-x11.cfg
index c9079b84f..8814f5e2f 100644
--- a/make/config/jogl/glx-x11.cfg
+++ b/make/config/jogl/glx-x11.cfg
@@ -3,7 +3,7 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/X11
-Package com.sun.opengl.impl.x11.glx
+Package com.jogamp.opengl.impl.x11.glx
JavaClass GLX
Style allstatic
Include gl-common.cfg
diff --git a/make/config/jogl/glxext.cfg b/make/config/jogl/glxext.cfg
index 39ba379c4..f07d5cc1b 100755
--- a/make/config/jogl/glxext.cfg
+++ b/make/config/jogl/glxext.cfg
@@ -3,13 +3,13 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/X11
-Package com.sun.opengl.impl.x11.glx
+Package com.jogamp.opengl.impl.x11.glx
Style InterfaceAndImpl
JavaClass GLXExt
-ImplPackage com.sun.opengl.impl.x11.glx
+ImplPackage com.jogamp.opengl.impl.x11.glx
ImplJavaClass GLXExtImpl
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/sun/opengl/impl/x11/glx/GLX.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/impl/x11/glx/GLX.java
Include gl-common.cfg
Include gl-desktop.cfg
diff --git a/make/config/jogl/wgl-win32.cfg b/make/config/jogl/wgl-win32.cfg
index 6cd4fd412..2a69290a4 100644
--- a/make/config/jogl/wgl-win32.cfg
+++ b/make/config/jogl/wgl-win32.cfg
@@ -3,7 +3,7 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/Windows
-Package com.sun.opengl.impl.windows.wgl
+Package com.jogamp.opengl.impl.windows.wgl
JavaClass WGL
Style allstatic
Include gl-common.cfg
diff --git a/make/config/jogl/wglext.cfg b/make/config/jogl/wglext.cfg
index ea9a0257e..35c43cb86 100644
--- a/make/config/jogl/wglext.cfg
+++ b/make/config/jogl/wglext.cfg
@@ -3,10 +3,10 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/Windows
-Package com.sun.opengl.impl.windows.wgl
+Package com.jogamp.opengl.impl.windows.wgl
Style InterfaceAndImpl
JavaClass WGLExt
-ImplPackage com.sun.opengl.impl.windows.wgl
+ImplPackage com.jogamp.opengl.impl.windows.wgl
ImplJavaClass WGLExtImpl
Include gl-common.cfg
Include gl-desktop.cfg
diff --git a/make/stub_includes/opengl/gl4.c b/make/stub_includes/opengl/gl4.c
new file mode 100644
index 000000000..cf8a709f7
--- /dev/null
+++ b/make/stub_includes/opengl/gl4.c
@@ -0,0 +1,11 @@
+#define GLAPI
+
+// Define GL4_PROTOTYPES so that the OpenGL prototypes in
+// "gl3.h" are parsed.
+#define GL4_PROTOTYPES
+
+// Define GL_GL4EXT_PROTOTYPES so that the OpenGL extension prototypes in
+// "gl3ext.h" are parsed.
+#define GL_GL4EXT_PROTOTYPES
+
+#include <GL4/gl3.h>
diff --git a/make/config/jogl/gl-impl-CustomCCode-gl2.c b/make/config/jogl/gl-impl-CustomCCode-gl2.c
index f97b8eaff..91fd0078b 100644
--- a/make/config/jogl/gl-impl-CustomCCode-gl2.c
+++ b/make/config/jogl/gl-impl-CustomCCode-gl2.c
@@ -1,10 +1,10 @@
/* Java->C glue code:
* Java package: com.sun.opengl.impl.gl2.GL2Impl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
*/
JNIEXPORT jlong JNICALL
-Java_com_sun_opengl_impl_gl2_GL2Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
+Java_com_jogamp_opengl_impl_gl2_GL2Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
PFNGLMAPBUFFERPROC ptr_glMapBuffer;
void * _res;
ptr_glMapBuffer = (PFNGLMAPBUFFERPROC) (intptr_t) glProcAddress;
@@ -14,11 +14,11 @@ Java_com_sun_opengl_impl_gl2_GL2Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject
}
/* Java->C glue code:
* Java package: com.sun.opengl.impl.gl2.GL2Impl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
*/
JNIEXPORT jobject JNICALL
-Java_com_sun_opengl_impl_gl2_GL2Impl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
+Java_com_jogamp_opengl_impl_gl2_GL2Impl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
return (*env)->NewDirectByteBuffer(env, (void*) (intptr_t) addr, capacity);
}
@@ -1,10 +1,10 @@
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.gl2.GL2Impl
+ * Java package: com.jogamp.opengl.impl.gl2.GL2Impl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
@@ -14,11 +14,11 @@ Java_com_sun_opengl_impl_gl2_GL2Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject
}
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.gl2.GL2Impl
+ * Java package: com.jogamp.opengl.impl.gl2.GL2Impl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
diff --git a/make/config/jogl/gl-impl-CustomCCode-gl2es12.c b/make/config/jogl/gl-impl-CustomCCode-gl2es12.c
index e2d5cb58d..07b821802 100644
--- a/make/config/jogl/gl-impl-CustomCCode-gl2es12.c
+++ b/make/config/jogl/gl-impl-CustomCCode-gl2es12.c
@@ -1,10 +1,10 @@
/* Java->C glue code:
* Java package: com.sun.opengl.impl.gl2es12.GL2ES12Impl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
*/
JNIEXPORT jlong JNICALL
-Java_com_sun_opengl_impl_gl2es12_GL2ES12Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
+Java_com_jogamp_opengl_impl_gl2es12_GL2ES12Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
PFNGLMAPBUFFERPROC ptr_glMapBuffer;
void * _res;
ptr_glMapBuffer = (PFNGLMAPBUFFERPROC) (intptr_t) glProcAddress;
@@ -14,11 +14,11 @@ Java_com_sun_opengl_impl_gl2es12_GL2ES12Impl_dispatch_1glMapBuffer(JNIEnv *env,
}
/* Java->C glue code:
* Java package: com.sun.opengl.impl.gl2es12.GL2ES12Impl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
*/
JNIEXPORT jobject JNICALL
-Java_com_sun_opengl_impl_gl2es12_GL2ES12Impl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
+Java_com_jogamp_opengl_impl_gl2es12_GL2ES12Impl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
return (*env)->NewDirectByteBuffer(env, (void*) (intptr_t) addr, capacity);
}
@@ -1,10 +1,10 @@
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.gl2es12.GL2ES12Impl
+ * Java package: com.jogamp.opengl.impl.gl2es12.GL2ES12Impl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
@@ -14,11 +14,11 @@ Java_com_sun_opengl_impl_gl2es12_GL2ES12Impl_dispatch_1glMapBuffer(JNIEnv *env,
}
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.gl2es12.GL2ES12Impl
+ * Java package: com.jogamp.opengl.impl.gl2es12.GL2ES12Impl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
diff --git a/make/config/jogl/gl-impl-CustomCCode-gl3.c b/make/config/jogl/gl-impl-CustomCCode-gl3.c
index a5f78a460..f540a7d4a 100644
--- a/make/config/jogl/gl-impl-CustomCCode-gl3.c
+++ b/make/config/jogl/gl-impl-CustomCCode-gl3.c
@@ -1,10 +1,10 @@
/* Java->C glue code:
* Java package: com.sun.opengl.impl.gl3.GL3Impl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
*/
JNIEXPORT jlong JNICALL
-Java_com_sun_opengl_impl_gl3_GL3Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
+Java_com_jogamp_opengl_impl_gl3_GL3Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
PFNGLMAPBUFFERPROC ptr_glMapBuffer;
void * _res;
ptr_glMapBuffer = (PFNGLMAPBUFFERPROC) (intptr_t) glProcAddress;
@@ -14,11 +14,11 @@ Java_com_sun_opengl_impl_gl3_GL3Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject
}
/* Java->C glue code:
* Java package: com.sun.opengl.impl.gl3.GL3Impl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
*/
JNIEXPORT jobject JNICALL
-Java_com_sun_opengl_impl_gl3_GL3Impl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
+Java_com_jogamp_opengl_impl_gl3_GL3Impl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
return (*env)->NewDirectByteBuffer(env, (void*) (intptr_t) addr, capacity);
}
@@ -1,10 +1,10 @@
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.gl3.GL3Impl
+ * Java package: com.jogamp.opengl.impl.gl3.GL3Impl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
@@ -14,11 +14,11 @@ Java_com_sun_opengl_impl_gl3_GL3Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject
}
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.gl3.GL3Impl
+ * Java package: com.jogamp.opengl.impl.gl3.GL3Impl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
diff --git a/make/config/jogl/gl-impl-CustomCCode-gl3bc.c b/make/config/jogl/gl-impl-CustomCCode-gl3bc.c
index a69204198..21de8c925 100644
--- a/make/config/jogl/gl-impl-CustomCCode-gl3bc.c
+++ b/make/config/jogl/gl-impl-CustomCCode-gl3bc.c
@@ -1,10 +1,10 @@
/* Java->C glue code:
* Java package: com.sun.opengl.impl.gl3.GL3bcImpl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
*/
JNIEXPORT jlong JNICALL
-Java_com_sun_opengl_impl_gl3_GL3bcImpl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
+Java_com_jogamp_opengl_impl_gl3_GL3bcImpl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
PFNGLMAPBUFFERPROC ptr_glMapBuffer;
void * _res;
ptr_glMapBuffer = (PFNGLMAPBUFFERPROC) (intptr_t) glProcAddress;
@@ -14,11 +14,11 @@ Java_com_sun_opengl_impl_gl3_GL3bcImpl_dispatch_1glMapBuffer(JNIEnv *env, jobjec
}
/* Java->C glue code:
* Java package: com.sun.opengl.impl.gl3.GL3bcImpl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
*/
JNIEXPORT jobject JNICALL
-Java_com_sun_opengl_impl_gl3_GL3bcImpl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
+Java_com_jogamp_opengl_impl_gl3_GL3bcImpl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
return (*env)->NewDirectByteBuffer(env, (void*) (intptr_t) addr, capacity);
}
@@ -1,10 +1,10 @@
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.gl3.GL3bcImpl
+ * Java package: com.jogamp.opengl.impl.gl3.GL3bcImpl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
@@ -14,11 +14,11 @@ Java_com_sun_opengl_impl_gl3_GL3bcImpl_dispatch_1glMapBuffer(JNIEnv *env, jobjec
}
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.gl3.GL3bcImpl
+ * Java package: com.jogamp.opengl.impl.gl3.GL3bcImpl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
diff --git a/make/config/jogl/gl-impl-CustomCCode-gles1.c b/make/config/jogl/gl-impl-CustomCCode-gles1.c
index efc614e64..a71ca4aae 100644
--- a/make/config/jogl/gl-impl-CustomCCode-gles1.c
+++ b/make/config/jogl/gl-impl-CustomCCode-gles1.c
@@ -1,11 +1,11 @@
typedef GLvoid* (GL_APIENTRY* PFNGLMAPBUFFERPROC) (GLenum target, GLenum access);
/* Java->C glue code:
* Java package: com.sun.opengl.impl.es1.GLES1Impl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
*/
JNIEXPORT jlong JNICALL
-Java_com_sun_opengl_impl_es1_GLES1Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
+Java_com_jogamp_opengl_impl_es1_GLES1Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
PFNGLMAPBUFFERPROC ptr_glMapBuffer;
void * _res;
ptr_glMapBuffer = (PFNGLMAPBUFFERPROC) (intptr_t) glProcAddress;
@@ -15,11 +15,11 @@ Java_com_sun_opengl_impl_es1_GLES1Impl_dispatch_1glMapBuffer(JNIEnv *env, jobjec
}
/* Java->C glue code:
* Java package: com.sun.opengl.impl.es1.GLES1Impl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
*/
JNIEXPORT jobject JNICALL
-Java_com_sun_opengl_impl_es1_GLES1Impl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
+Java_com_jogamp_opengl_impl_es1_GLES1Impl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
return (*env)->NewDirectByteBuffer(env, (void*) (intptr_t) addr, capacity);
}
@@ -1,11 +1,11 @@
typedef GLvoid* (GL_APIENTRY* PFNGLMAPBUFFERPROC) (GLenum target, GLenum access);
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.es1.GLES1Impl
+ * Java package: com.jogamp.opengl.impl.es1.GLES1Impl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
@@ -15,11 +15,11 @@ Java_com_sun_opengl_impl_es1_GLES1Impl_dispatch_1glMapBuffer(JNIEnv *env, jobjec
}
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.es1.GLES1Impl
+ * Java package: com.jogamp.opengl.impl.es1.GLES1Impl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
diff --git a/make/config/jogl/gl-impl-CustomCCode-gles2.c b/make/config/jogl/gl-impl-CustomCCode-gles2.c
index 27be04749..f99822d65 100644
--- a/make/config/jogl/gl-impl-CustomCCode-gles2.c
+++ b/make/config/jogl/gl-impl-CustomCCode-gles2.c
@@ -1,11 +1,11 @@
typedef GLvoid* (GL_APIENTRY* PFNGLMAPBUFFERPROC) (GLenum target, GLenum access);
/* Java->C glue code:
* Java package: com.sun.opengl.impl.es2.GLES2Impl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
*/
JNIEXPORT jlong JNICALL
-Java_com_sun_opengl_impl_es2_GLES2Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
+Java_com_jogamp_opengl_impl_es2_GLES2Impl_dispatch_1glMapBuffer(JNIEnv *env, jobject _unused, jint target, jint access, jlong glProcAddress) {
PFNGLMAPBUFFERPROC ptr_glMapBuffer;
void * _res;
ptr_glMapBuffer = (PFNGLMAPBUFFERPROC) (intptr_t) glProcAddress;
@@ -15,11 +15,11 @@ Java_com_sun_opengl_impl_es2_GLES2Impl_dispatch_1glMapBuffer(JNIEnv *env, jobjec
}
/* Java->C glue code:
* Java package: com.sun.opengl.impl.es2.GLES2Impl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
*/
JNIEXPORT jobject JNICALL
-Java_com_sun_opengl_impl_es2_GLES2Impl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
+Java_com_jogamp_opengl_impl_es2_GLES2Impl_newDirectByteBuffer(JNIEnv *env, jobject _unused, jlong addr, jint capacity) {
return (*env)->NewDirectByteBuffer(env, (void*) (intptr_t) addr, capacity);
}
@@ -1,11 +1,11 @@
typedef GLvoid* (GL_APIENTRY* PFNGLMAPBUFFERPROC) (GLenum target, GLenum access);
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.es2.GLES2Impl
+ * Java package: com.jogamp.opengl.impl.es2.GLES2Impl
* Java method: long dispatch_glMapBuffer(int target, int access)
* C function: void * glMapBuffer(GLenum target, GLenum access);
@@ -15,11 +15,11 @@ Java_com_sun_opengl_impl_es2_GLES2Impl_dispatch_1glMapBuffer(JNIEnv *env, jobjec
}
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.es2.GLES2Impl
+ * Java package: com.jogamp.opengl.impl.es2.GLES2Impl
* Java method: ByteBuffer newDirectByteBuffer(long addr, int capacity);
* C function: jobject newDirectByteBuffer(jlong addr, jint capacity);
diff --git a/make/config/jogl/glx-CustomCCode.c b/make/config/jogl/glx-CustomCCode.c
index a075c4852..7dac53fb6 100755
--- a/make/config/jogl/glx-CustomCCode.c
+++ b/make/config/jogl/glx-CustomCCode.c
@@ -15,7 +15,7 @@
/* We expect glXGetProcAddressARB to be defined */
extern void (*glXGetProcAddressARB(const GLubyte *procname))();
-static const char * clazzNameInternalBufferUtil = "com/sun/opengl/impl/InternalBufferUtil";
+static const char * clazzNameInternalBufferUtil = "com/jogamp/opengl/impl/InternalBufferUtil";
static const char * clazzNameInternalBufferUtilStaticCstrName = "copyByteBuffer";
static const char * clazzNameInternalBufferUtilStaticCstrSignature = "(Ljava/nio/ByteBuffer;)Ljava/nio/ByteBuffer;";
static const char * clazzNameByteBuffer = "java/nio/ByteBuffer";
@@ -30,29 +30,29 @@ static void _initClazzAccess(JNIEnv *env) {
c = (*env)->FindClass(env, clazzNameInternalBufferUtil);
if(NULL==c) {
- fprintf(stderr, "FatalError: Java_com_sun_opengl_impl_x11_glx_GLX: can't find %s\n", clazzNameInternalBufferUtil);
+ fprintf(stderr, "FatalError: Java_com_jogamp_opengl_impl_x11_glx_GLX: can't find %s\n", clazzNameInternalBufferUtil);
(*env)->FatalError(env, clazzNameInternalBufferUtil);
}
clazzInternalBufferUtil = (jclass)(*env)->NewGlobalRef(env, c);
if(NULL==clazzInternalBufferUtil) {
- fprintf(stderr, "FatalError: Java_com_sun_opengl_impl_x11_glx_GLX: can't use %s\n", clazzNameInternalBufferUtil);
+ fprintf(stderr, "FatalError: Java_com_jogamp_opengl_impl_x11_glx_GLX: can't use %s\n", clazzNameInternalBufferUtil);
(*env)->FatalError(env, clazzNameInternalBufferUtil);
}
c = (*env)->FindClass(env, clazzNameByteBuffer);
if(NULL==c) {
- fprintf(stderr, "FatalError: Java_com_sun_opengl_impl_x11_glx_GLX: can't find %s\n", clazzNameByteBuffer);
+ fprintf(stderr, "FatalError: Java_com_jogamp_opengl_impl_x11_glx_GLX: can't find %s\n", clazzNameByteBuffer);
(*env)->FatalError(env, clazzNameByteBuffer);
}
clazzByteBuffer = (jclass)(*env)->NewGlobalRef(env, c);
if(NULL==c) {
- fprintf(stderr, "FatalError: Java_com_sun_opengl_impl_x11_glx_GLX: can't use %s\n", clazzNameByteBuffer);
+ fprintf(stderr, "FatalError: Java_com_jogamp_opengl_impl_x11_glx_GLX: can't use %s\n", clazzNameByteBuffer);
(*env)->FatalError(env, clazzNameByteBuffer);
}
cstrInternalBufferUtil = (*env)->GetStaticMethodID(env, clazzInternalBufferUtil,
clazzNameInternalBufferUtilStaticCstrName, clazzNameInternalBufferUtilStaticCstrSignature);
if(NULL==cstrInternalBufferUtil) {
- fprintf(stderr, "FatalError: Java_com_sun_opengl_impl_x11_glx_GLX:: can't create %s.%s %s\n",
+ fprintf(stderr, "FatalError: Java_com_jogamp_opengl_impl_x11_glx_GLX:: can't create %s.%s %s\n",
clazzNameInternalBufferUtil,
clazzNameInternalBufferUtilStaticCstrName, clazzNameInternalBufferUtilStaticCstrSignature);
(*env)->FatalError(env, clazzNameInternalBufferUtilStaticCstrName);
@@ -60,12 +60,12 @@ static void _initClazzAccess(JNIEnv *env) {
}
/* Java->C glue code:
* Java package: com.sun.opengl.impl.x11.glx.GLX
* Java method: XVisualInfo glXGetVisualFromFBConfig(long dpy, long config)
* C function: XVisualInfo * glXGetVisualFromFBConfig(Display * dpy, GLXFBConfig config);
*/
JNIEXPORT jobject JNICALL
-Java_com_sun_opengl_impl_x11_glx_GLX_glXGetVisualFromFBConfigCopied0__JJ(JNIEnv *env, jclass _unused, jlong dpy, jlong config) {
+Java_com_jogamp_opengl_impl_x11_glx_GLX_glXGetVisualFromFBConfigCopied0__JJ(JNIEnv *env, jclass _unused, jlong dpy, jlong config) {
XVisualInfo * _res;
jobject jbyteSource;
jobject jbyteCopy;
@@ -85,12 +85,12 @@ Java_com_sun_opengl_impl_x11_glx_GLX_glXGetVisualFromFBConfigCopied0__JJ(JNIEnv
}
/* Java->C glue code:
* Java package: com.sun.opengl.impl.x11.glx.GLX
* Java method: java.nio.LongBuffer glXChooseFBConfig(long dpy, int screen, java.nio.IntBuffer attribList, java.nio.IntBuffer nitems)
* C function: GLXFBConfig * glXChooseFBConfig(Display * dpy, int screen, const int * attribList, int * nitems);
*/
JNIEXPORT jobject JNICALL
-Java_com_sun_opengl_impl_x11_glx_GLX_glXChooseFBConfigCopied1__JILjava_lang_Object_2ILjava_lang_Object_2I(JNIEnv *env, jclass _unused, jlong dpy, jint screen, jobject attribList, jint attribList_byte_offset, jobject nitems, jint nitems_byte_offset) {
+Java_com_jogamp_opengl_impl_x11_glx_GLX_glXChooseFBConfigCopied1__JILjava_lang_Object_2ILjava_lang_Object_2I(JNIEnv *env, jclass _unused, jlong dpy, jint screen, jobject attribList, jint attribList_byte_offset, jobject nitems, jint nitems_byte_offset) {
int * _ptr2 = NULL;
int * _ptr3 = NULL;
GLXFBConfig * _res;
@@ -126,12 +126,12 @@ Java_com_sun_opengl_impl_x11_glx_GLX_glXChooseFBConfigCopied1__JILjava_lang_Obje
}
/* Java->C glue code:
* Java package: com.sun.opengl.impl.x11.glx.GLX
* Java method: XVisualInfo glXChooseVisual(long dpy, int screen, java.nio.IntBuffer attribList)
* C function: XVisualInfo * glXChooseVisual(Display * dpy, int screen, int * attribList);
*/
JNIEXPORT jobject JNICALL
-Java_com_sun_opengl_impl_x11_glx_GLX_glXChooseVisualCopied1__JILjava_lang_Object_2I(JNIEnv *env, jclass _unused, jlong dpy, jint screen, jobject attribList, jint attribList_byte_offset) {
+Java_com_jogamp_opengl_impl_x11_glx_GLX_glXChooseVisualCopied1__JILjava_lang_Object_2I(JNIEnv *env, jclass _unused, jlong dpy, jint screen, jobject attribList, jint attribList_byte_offset) {
int * _ptr2 = NULL;
XVisualInfo * _res;
jobject jbyteSource;
@@ -60,12 +60,12 @@ static void _initClazzAccess(JNIEnv *env) {
}
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.x11.glx.GLX
+ * Java package: com.jogamp.opengl.impl.x11.glx.GLX
* Java method: XVisualInfo glXGetVisualFromFBConfig(long dpy, long config)
* C function: XVisualInfo * glXGetVisualFromFBConfig(Display * dpy, GLXFBConfig config);
@@ -85,12 +85,12 @@ Java_com_sun_opengl_impl_x11_glx_GLX_glXGetVisualFromFBConfigCopied0__JJ(JNIEnv
}
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.x11.glx.GLX
+ * Java package: com.jogamp.opengl.impl.x11.glx.GLX
* Java method: java.nio.LongBuffer glXChooseFBConfig(long dpy, int screen, java.nio.IntBuffer attribList, java.nio.IntBuffer nitems)
* C function: GLXFBConfig * glXChooseFBConfig(Display * dpy, int screen, const int * attribList, int * nitems);
@@ -126,12 +126,12 @@ Java_com_sun_opengl_impl_x11_glx_GLX_glXChooseFBConfigCopied1__JILjava_lang_Obje
}
/* Java->C glue code:
- * Java package: com.sun.opengl.impl.x11.glx.GLX
+ * Java package: com.jogamp.opengl.impl.x11.glx.GLX
* Java method: XVisualInfo glXChooseVisual(long dpy, int screen, java.nio.IntBuffer attribList)
* C function: XVisualInfo * glXChooseVisual(Display * dpy, int screen, int * attribList);